@@ -23,6 +23,12 @@ typedef struct {
   XImage *ximage;
 } VScreenType;
 
+extern int icon48_nr_colors;
+extern int icon48_cols;
+extern int icon48_rows;
+extern char icon48_colors[];
+extern char icon48_pixels[];
+
 void SetCustomPalette(void);
 void CopyToScreen(void);
 Pixmap create_icon(void);
