@@ -9,9 +9,7 @@ void clearscr(void);
 void putarea(unsigned char *source,
 	     int x, int y, int width, int height, int bytesperline,
 	     int destx, int desty);
-void puthline(unsigned char *source, int x, int y, int length);
 void putpixel(int x, int y, unsigned char color);
-int getpixel(int x, int y);
 void syncscreen(void);
 void displayscreen(void);
 void fade_in(void);
