@@ -22,9 +22,9 @@
 #include <ctype.h>
 #include <math.h>
 
-#include "thrust_types.h"
+#include "thrust_t.h"
 #include "thrust.h"
-#include "highscore.h"
+#include "hiscore.h"
 #include "graphics.h"
 #include "fast_gr.h"
 #include "gr_drv.h"
@@ -37,17 +37,17 @@
 #include "options.h"
 
 #ifdef HAVE_SOUND
-#include "soundIt.h"
+# include "soundIt.h"
 
-#define CHAN_1 0
-#define CHAN_2 1
-#define CHAN_3 2
-#define CHAN_4 3
-#define SND_BOOM   0
-#define SND_BOOM2  1
-#define SND_HARP   2
-#define SND_THRUST 3
-#define SND_ZERO   4
+# define CHAN_1 0
+# define CHAN_2 1
+# define CHAN_3 2
+# define CHAN_4 3
+# define SND_BOOM   0
+# define SND_BOOM2  1
+# define SND_HARP   2
+# define SND_THRUST 3
+# define SND_ZERO   4
 #endif
 
 byte *bulletmap;
@@ -93,6 +93,7 @@ int nodemo=0;
 int Thrust_Is_On=0;
 int play_sound=1;
 double gamma_correction=1.0;
+int skip_frames=0;
 
 #define checkfork(b, a) \
   case b-1: \
@@ -145,8 +146,8 @@ void
 pause_message(void)
 {
   char *str[] = {
-    "GAME PAUSED.",
-    "PRESS 'C' TO CONTINUE..." };
+    "Game paused.",
+    "Press 'C' to continue..." };
 
   chflag=1;
   gcenter(80, str[0]);
@@ -159,7 +160,7 @@ void
 escape_message(void)
 {
   char *str[] = {
-    "ARE YOU SURE YOU WANT TO QUIT (Y/N)?" };
+    "Are you sure you want to quit (Y/N)?" };
 
   chflag=1;
   gcenter(85, str[0]);
@@ -170,7 +171,7 @@ escape_message(void)
 byte
 whatkeys(void)
 {
-  byte keys=0;
+  byte keys;
 
 /* Use this to create a demo.
  * Don't forget to uncomment the fputc statement below.
@@ -197,7 +198,7 @@ nextmove(int reset)
 
   if(reset) {
     keywaiting();
-    p=&bin_demomoves[0];
+    p=&bin_demomove[0];
   }
   else if(keywaiting()) {
     retbits=quit_bit;
@@ -212,6 +213,67 @@ nextmove(int reset)
   return(retbits);
 }
 
+void
+gamestatusframe(void)
+{
+  int i, maxx;
+
+  for(i=3; i<317; i++)
+    putpixel(i, 3, 0x88);
+  for(i=3; i<11; i++) {
+    putpixel(  3, i, 0x88);
+    putpixel(  4, i, 0x88);
+    putpixel(315, i, 0x88);
+    putpixel(316, i, 0x88);
+  }
+  for(i=3; i<11; i++) {
+    putpixel(    i, i+8, 0x88);
+    putpixel(  1+i, i+8, 0x88);
+    putpixel(318-i, i+8, 0x88);
+    putpixel(319-i, i+8, 0x88);
+  }
+  for(i=9; i<311; i++)
+    putpixel(i, 18, 0x88);
+  maxx = 80-gstrlen("FUEL")-2;
+  for(i=6; i<maxx; i++) {
+    putpixel(i, 6, 65);
+    putpixel(i, 8, 65);
+  }
+  maxx = 160-gstrlen("LIVES")/2-2;
+  for(i=82; i<maxx; i++) {
+    putpixel(i, 6, 65);
+    putpixel(i, 8, 65);
+  }
+  maxx = 280-gstrlen("SCORE")-2;
+  for(i=160+gstrlen("LIVES")/2+2; i<maxx; i++) {
+    putpixel(i, 6, 65);
+    putpixel(i, 8, 65);
+  }
+  for(i=282; i<313; i++) {
+    putpixel(i, 6, 65);
+    putpixel(i, 8, 65);
+  }
+  chcolor = 0x89;
+  printgs(80-gstrlen("FUEL"), 5, "FUEL");
+  gcenter(5, "LIVES");
+  printgs(280-gstrlen("SCORE"), 5, "SCORE");
+  chcolor = TEXTCOLOR;
+}
+
+void
+gamestatus(int lives, int fuel, int score)
+{
+  static char textstr[40];
+
+  chcolor = 0x88;
+  drawfuel(fuel);
+  sprintf(textstr, "%d", lives);
+  gcenter(12, textstr);
+  sprintf(textstr, "%d", score);
+  printgs(280-gstrlen(textstr), 12, textstr);
+  chcolor = TEXTCOLOR;
+}
+
 int
 game(int demo)
 {
@@ -222,7 +284,6 @@ game(int demo)
   word alive;
   word fuel;
   int l;
-  word wrapers;
   int level;
   int round;
   static char **levels[LEVELS]
@@ -237,6 +298,7 @@ game(int demo)
   int loadedrestart=0;
   restartpoint *restartxy;
   int gravitymsg;
+  int visibilitymsg;
   int teleport;
 
   if(demo)
@@ -251,55 +313,60 @@ game(int demo)
   shield=0;
   fuel=1000; /* 1000 */
   gravitymsg=0;
+  visibilitymsg=0;
   teleport=0;
 
   while(level<LEVELS && lives>0 && fuel) {
 #ifdef DEBUG2
     printf("Newlevel: %d\n", level);
 #endif
-    endlevel=0;
-    wrapers=0;
-    dying=0;
-    alive=1;
+    endlevel = 0;
+    dying    = 0;
+    alive    = 1;
     
     srandom(time(NULL));
-    if(level!=lastlevel || !spacestation) {
-      if(level==0 && lastlevel>0)
-	gravitymsg=1;
+    if(level!=lastlevel || !powerplant) {
+      if(level==0 && lastlevel>0) {
+	gravitymsg = 1;
+	if(round == 2)
+	  visibilitymsg = 1;
+      }
       if(!readbana(levels[level])) {
 	printf("Illegal definition of level %d.\n", level+1);
 	return(1);
       }
-      restartx=(lenx+restartpoints[0].x-(154>>3))%lenx;
-      restarty=restartpoints[0].y-(82>>3)-4*(round&1);
-      loadedrestart=0;
+      restartx = (lenx+restartpoints[0].x-(154>>3))%lenx;
+      restarty = restartpoints[0].y-(82>>3)-4*(round&1);
+      loadedrestart = 0;
       initgame(round, 1, restartx, restarty);
     }
     else {
-      loaded=loadedrestart;
+      loaded = loadedrestart;
       initgame(round, 0, restartx, restarty);
     }
 
     initscreen(round);
-    putscr(pixx%PBILDX, pixy%PBILDY);
-    lastlevel=level;
+    putscr(pixx%PBILDX, pixy%PBILDY, 1);
+    lastlevel = level;
 
-    printgs(250, 184, "FUEL");
-    sprintf(textstr, "LIVES: %d", lives);
-    printgs(20, 192, textstr);
-    sprintf(textstr, "SCORE: %d", score);
-    printgs(20, 184, textstr);
-    sprintf(textstr, "LEVEL %d",  level+1);
+    gamestatusframe();
+    gamestatus(lives, fuel, score);
+    sprintf(textstr, "Level %d",  level+1);
     gcenter(70, textstr);
-    if(gravitymsg)
-      gcenter(60, (round&1) ? "REVERSED GRAVITY": "NORMAL GRAVITY");
-    gravitymsg=0;
+    if(gravitymsg) {
+      gcenter(60, (round&1) ? "Reversed gravity" : "Normal gravity");
+      if(visibilitymsg)
+	gcenter(52, (round&2) ? "Invisible ground" : "Visible ground");
+    }
     displayscreen();
     syncscreen();
     fade_in();
-    usleep(1000000UL);
+    usleep(1000000UL + 2000000UL*gravitymsg);
+    gravitymsg=0;
     syncscreen();
-    putscr(pixx%PBILDX, pixy%PBILDY);
+    putscr(pixx%PBILDX, pixy%PBILDY, 1);
+    drawteleport(1);
+    displayscreen();
     while(!endlevel) {
       actionbits=demo ? nextmove(0) : whatkeys();
 
@@ -318,7 +385,7 @@ game(int demo)
 	}
 #endif
 	pause_message();
-	keyclose();
+	singlekey();
 	end=NOTHING;
 	while(getkey());
 	while(end==NOTHING) {
@@ -345,11 +412,11 @@ game(int demo)
 	    end=PLAY;
 	    break;
 	  }
-	  usleep(10000UL);
+	  usleep(50000UL);
 	}
 	if(easyrider!=9)
 	  easyrider=0;
-	keyinit();
+	multiplekeys();
       }
       if(actionbits&escape_bit) {
 #ifdef HAVE_SOUND
@@ -359,7 +426,7 @@ game(int demo)
 	}
 #endif
 	escape_message();
-	keyclose();
+	singlekey();
 	end=NOTHING;
 	while(end==NOTHING) {
 	  ch=getkey();
@@ -376,9 +443,9 @@ game(int demo)
 	    end=PLAY;
 	    break;
 	  }
-	  usleep(10000UL);
+	  usleep(50000UL);
 	}
-	keyinit();
+	multiplekeys();
       }
       if(alive && (actionbits&right_bit)) {
 	decr(kdir, 0, 96);
@@ -391,8 +458,8 @@ game(int demo)
       if(alive && (actionbits&fire_bit)) {
 	if(!shoot) {
 	  shoot=1;
-	  newbullet(x+((160+shipdx)<<3)+64*cos(dir * M_PI/16),
-		    y+(( 88+shipdy)<<3)-64*sin(dir * M_PI/16),
+	  newbullet(x+((160+shipdx)<<3)+74*cos(dir * M_PI/16),
+		    y+(( 88+shipdy)<<3)-74*sin(dir * M_PI/16),
 		    speedx/256.0+32*cos(dir * M_PI/16),
 		    speedy/256.0+32*sin(dir * M_PI/16),
 		    kdir/6, 1);
@@ -562,38 +629,34 @@ game(int demo)
       }
 
       /* Bunkerfire */
-      if(!ssblip)
+      if(!ppblip)
 	bunkerfirebullets();
       movebullets();
       movefragments();
       drawfuel(fuel);
 
-      /* Move the Spacestationblip */
-      scount=(scount+1)&15;
-      if(!scount && spacestation && ssblip)
-	ssblip--;
+      /* Move the Power Plant blip */
+      ppcount=(ppcount+1)&15;
+      if(!ppcount && powerplant && ppblip)
+	ppblip--;
 
-      if(!spacestation) {
+      if(!powerplant) {
 	countdown--;
 	if(countdown<0) {
 #ifndef DEBUG
 	  if(alive && !easyrider) {
 	    dying=1;
 #ifdef DEBUG2
-	    printf("Dying: Spacestation countdown.\n");
+	    printf("Dying: Power Plant countdown.\n");
 #endif
 	  }
 #endif
 	}
 	else {
 	  chflag=1;
-	  if(countdown&16)
-	    chcolor=0;
-	  else
-	    chcolor=TEXTCOLOR;
 	  sprintf(textstr, "%d  ", (countdown+99)/100);
-	  printgs(155, 180, textstr);
-	  chcolor=TEXTCOLOR;
+	  printgs(105, 12, textstr);
+	  printgs(205, 12, textstr);
 	  chflag=0;
 	}
       }
@@ -607,30 +670,16 @@ game(int demo)
       pblocky=pixy>>3;
       bblockx=bildx>>3;
       bblocky=bildy>>3;
-      if(wrapers)
-	if(pblocky>BBILDY && pblocky<2*BBILDY) {
-	  y-=PBILDY<<3;
-	  pixy-=PBILDY;
-	  pblocky-=BBILDY;
-	  unwrapbullets();
-	  unwrapfragments();
-	  wrapers--;
-	}
+
       if(pblocky>leny-3) {
-	/*	if(loaded) {*/
-	  endlevel=1;
+	endlevel=1;
 #ifdef DEBUG2
-	  printf("Endlevel: Finished level.\n");
+	printf("Endlevel: Finished level.\n");
 #endif
-	  teleport=1;
-	  /*	}*/
-	y+=(PBILDY-leny3)<<3;
-	pixy+=PBILDY-leny3;
-	pblocky+=BBILDY-leny;
-	wrapbullets();
-	wrapfragments();
-	if(!++wrapers)
-	  wrapers--;
+	teleport=1;
+	y=0;
+	pixy=0;
+	pblocky=0;
       }
 
       /* Check if at a restart barrier. If so, update the restart point. */
@@ -643,11 +692,9 @@ game(int demo)
       }
 
       /* Scroll the screen */
-      setmargin(253, 1);
       updateborder(pblockx, pblocky, bblockx, bblocky, vx, vy);
       
-      drawspacestationblip();
-      setmargin(255, 1);
+      drawpowerplantblip();
       drawbullets();
       if(alive)
 	crash=drawshuttle();
@@ -668,15 +715,13 @@ game(int demo)
       /* Wait for the screen retrace and then dump the graphics to it. */
       /* Screendump */
 
-/*	if(keyboard_keypressed(63)) *//* F5 */
-/*	  savegraphics(bildx, bildy);*/
       syncscreen();
-      putscr(bildx, bildy);
+      putscr(bildx, bildy, 0);
+      displayscreen();
 
       /* Remove moveable objects from screen in reverse order. */
       if(alive && refueling)
 	undrawfuellines();
-      setmargin(120, 1);
       undrawfragments();
       if(alive)
 	undrawshuttle();
@@ -714,14 +759,10 @@ game(int demo)
       animatesliders();
       if(localscore>score) {
 	chflag=1;
-	if(localscore/10000 > score/10000) {
+	if(localscore/10000 > score/10000)
 	  lives++;
-	  sprintf(textstr, "LIVES: %d", lives);
-	  printgs(20, 192, textstr);
-	}
 	score=localscore;
-	sprintf(textstr, "SCORE: %d         ", score);
-	printgs(20, 184, textstr);
+	gamestatus(lives, fuel, score);
 	chflag=0;	
       }
     }
@@ -730,11 +771,11 @@ game(int demo)
       if(play_sound)
 	Snd_effect(SND_ZERO, CHAN_1);
 #endif
-      bin_colors[65*3+0]=colorr;
-      bin_colors[65*3+1]=colorg;
-      bin_colors[65*3+2]=colorb;
+      bin_colors[65*3+0]=GAMMA(colorr);
+      bin_colors[65*3+1]=GAMMA(colorg);
+      bin_colors[65*3+2]=GAMMA(colorb);
       fadepalette(0, 255, bin_colors, 64, 1);
-      drawteleport();
+      drawteleport(0);
     }
 
     if(!(actionbits&(quit_bit|escape_bit)))
@@ -742,55 +783,47 @@ game(int demo)
     fade_out();
 
     if(!demo && !(actionbits&(quit_bit|escape_bit))) {
-      if(teleport || !spacestation) {
+      if(teleport || !powerplant) {
 	chflag=1;
-	printgs(250, 184, "FUEL");
-	drawfuel(fuel);
-	sprintf(textstr, "LIVES: %d", lives);
-	printgs(20, 192, textstr);
-	sprintf(textstr, "SCORE: %d         ", score);
-	printgs(20, 184, textstr);
+	gamestatusframe();
+	gamestatus(lives, fuel, score);
 
-	if(!spacestation) {
-	  sprintf(textstr, "PLANET DESTROYED");
+	if(!powerplant) {
+	  sprintf(textstr, "Planet destroyed");
 	  gcenter(61, textstr);
 	}
 
 	if(teleport && loaded)
-	  sprintf(textstr, "MISSION %d COMPLETE", level+1);
-	else if(spacestation)
-	  sprintf(textstr, "MISSION INCOMPLETE");
+	  sprintf(textstr, "Mission %d complete", level+1);
+	else if(powerplant)
+	  sprintf(textstr, "Mission incomplete");
 	else
-	  sprintf(textstr, "MISSION  %d  FAILED", level+1);
-	gcenter(73-6*(teleport && loaded && spacestation), textstr);
+	  sprintf(textstr, "Misson  %d  failed", level+1);
+	gcenter(73-6*(teleport && loaded && powerplant), textstr);
 
-	if((teleport && loaded) || !spacestation) {
+	if((teleport && loaded) || !powerplant) {
 	  if(teleport && loaded)
-	    sprintf(textstr, "BONUS %d", 4000+400*level-2000*spacestation);
+	    sprintf(textstr, "Bonus %d", 4000+400*level-2000*powerplant);
 	  else
-	    sprintf(textstr, "NO BONUS");
-	  gcenter(85-6*(!!spacestation), textstr);
+	    sprintf(textstr, "No bonus");
+	  gcenter(85-6*(!!powerplant), textstr);
 	}
 
 	displayscreen();
 	fade_in();
 	usleep(2000000UL);
 	if(!easyrider && teleport && loaded)
-	  localscore+=4000+400*level-2000*spacestation;
-	if((teleport && loaded) || !spacestation) {
+	  localscore+=4000+400*level-2000*powerplant;
+	if((teleport && loaded) || !powerplant) {
 	  if(++level==LEVELS) {
 	    level=0;
 	    round=(round+1)%4;
 	  }
 	}
-	if(localscore/10000 > score/10000) {
+	if(localscore/10000 > score/10000)
 	  lives++;
-	  sprintf(textstr, "LIVES: %d", lives);
-	  printgs(20, 192, textstr);
-	}
 	score=localscore;
-	sprintf(textstr, "SCORE: %d         ", score);
-	printgs(20, 184, textstr);
+	gamestatus(lives, fuel, score);
 	chflag=0;
 	displayscreen();
 	usleep(2000000UL);
@@ -805,14 +838,10 @@ game(int demo)
 
   if(!demo) {
     chflag=1;
-    printgs(250, 184, "FUEL");
-    drawfuel(fuel);
-    sprintf(textstr, "LIVES: %d", lives);
-    printgs(20, 192, textstr);
-    sprintf(textstr, "SCORE: %d         ", score);
-    printgs(20, 184, textstr);
+    gamestatusframe();
+    gamestatus(lives, fuel, score);
 
-    gcenter(73, "GAME OVER");
+    gcenter(73, "Game Over");
 
     displayscreen();
     fade_in();
@@ -826,13 +855,13 @@ game(int demo)
 void
 pressanykey(void)
 {
-  keyclose();
+  singlekey();
 
   do 
-    usleep(10000UL);
+    usleep(50000UL);
   while(!getkey());
 
-  keyinit();
+  multiplekeys();
 }
 
 int
@@ -840,12 +869,76 @@ instructions(void)
 {
   int i;
   static char *keys[] = {
-    "ESC", "P", "C" };
+    "Esc", "P", "C" };
   static char *func[] = {
-    "TURN LEFT", "TURN RIGHT", "THRUST", "FIRE",
-    "PICK UP & SHIELD", "QUIT GAME (Q=ESC)", "PAUSE", "CONTINUE" };
+    "Turn left", "Turn right", "Thrust", "Fire",
+    "Pick up & Shield", "Quit Game (Q=Esc)", "Pause", "Continue" };
+  static char *story[] = {
+    "The resistance is about to launch a major offensive against",
+    "the Intergalactic Empire. In preparation for this, they have",
+    "captured several battle-grade starships, but they lack the",
+    "essential power sources for these formidable craft; Klystron",
+    "Pods. You have been commissioned by resistance to steal these",
+    "pods from the Empire's storage planets. Each planet is",
+    "defended by a battery of 'Limpet' guns, powered by a nuclear",
+    "power plant. By firing shots at the power plant, the guns can",
+    "be temporarily disabled; the more shots fired at the nuclear",
+    "reactor, the longer the guns will take to recharge.",
+    "BUT BEWARE!! If you fire too many shots at the reactor, it",
+    "will become critical, giving you just ten seconds to clear",
+    "the plantet before it is destroyed. If you have not already",
+    "retrieved the pod stored at the planet, then you will have",
+    "failed the mission. If you have retrieved the pod, and you",
+    "manage to send the reactor into its critical phase, and",
+    "leave the planet safely, you will receive a hefty bonus.",
+    NULL };
+  static char *score[] = {
+    "Destroying a limpet gun:",
+    "Destroying a fuel cell:",
+    "Picking up a fuel cell:",
+    "Bonus for destroying planet:",
+    "",
+    "A spare ship is allocated for every:"
+  };
+  static char *scores[] = {
+    "750",
+    "150",
+    "300",
+    "2000 + Mission Bonus",
+    "",
+    "10000"
+  };
 
-  gcenter(50, "THE FOLLOWING KEYS ARE USED:");
+  chcolor = HIGHLIGHT;
+  gcenter(20, "THE SILLY STORY!");
+  chcolor = TEXTCOLOR;
+  for(i=0; story[i]; i++)
+    gcenter(35 + i*8, story[i]);
+
+  gcenter(180, "Press any key for the next page.");
+
+  fade_in();
+  pressanykey();
+  fade_out();
+
+  chcolor = HIGHLIGHT;
+  gcenter(40, "SCORING");
+  chcolor = TEXTCOLOR;
+  for(i=0; i<6; i++) {
+    chcolor = TEXTCOLOR;
+    printgs(200-gstrlen(score[i]), 65 + 8*i, score[i]);
+    chcolor = HIGHLIGHT;
+    printgs(205, 65 + 8*i, scores[i]);
+  }
+
+  chcolor = TEXTCOLOR;
+  gcenter(130, "Press any key for the next page.");
+
+  fade_in();
+  pressanykey();
+  fade_out();
+
+  gcenter(50, "The following keys are used:");
   for(i=0; i<8; i++) {
     chcolor = HIGHLIGHT;
     if(i<5)
@@ -857,7 +950,7 @@ instructions(void)
     chcolor = TEXTCOLOR;
     printgs(145, 63+i*8+2*(i>4), func[i]);
   }
-  gcenter(150, "PRESS ANY KEY FOR THE MAIN MENU.");
+  gcenter(150, "Press any key for the main menu.");
 
   fade_in();
   pressanykey();
@@ -869,33 +962,29 @@ instructions(void)
 int
 about(void)
 {
-  int i, j;
-  char tmp[100];
+  int i;
   static char *str[] = {
-    "THRUST VERSION " VERSION,
+    "Thrust version " VERSION,
     "",
-    "WRITTEN BY",
+    "Written by",
     "",
-    "PETER EKBERG",
-    "PEDA@LYSATOR.LIU.SE",
+    "Peter Ekberg",
+    "peda@lysator.liu.se",
     "",
-    "THANKS TO THE AUTHORS",
-    "OF THE ORIGINAL",
-    "FOR THE C64.",
+    "Thanks to the authors",
+    "of the original",
+    "for the C64.",
     NULL
   };
 
   for(i=0; str[i]; i++) {
-    for(j=0; j<strlen(str[i]); j++)
-      tmp[j] = toupper(str[i][j]);
-    tmp[j]='\0';
     if(i==5)
       chcolor = HIGHLIGHT;
     else
       chcolor = TEXTCOLOR;
-    gcenter(40+9*i, tmp);
+    gcenter(40+9*i, str[i]);
   }
-  gcenter(145, "PRESS ANY KEY FOR MAIN MENU.");
+  gcenter(145, "Press any key for the main menu.");
 
   fade_in();
   pressanykey();
@@ -911,19 +1000,19 @@ enterhighscorename(void)
   char str[40];
   
   strcpy(name, standardname());
-  sprintf(str, "YOU MANAGED %d POINTS!", score);
+  sprintf(str, "You managed %d points!", score);
   gcenter(64, str);
-  gcenter(75, "YOU MADE IT INTO THE HIGHSCORE LIST!");
-  gcenter(86, "ENTER YOUR NAME:");
+  gcenter(75, "You made it into the highscore list!");
+  gcenter(86, "Enter your name:");
   printgs(130, 97, name);
   fade_in();
 
-  keyclose();
+  singlekey();
 
   if(readgs(130, 97, name, 39, 80, 0)==-1)
     strcpy(name, standardname());
 
-  keyinit();
+  multiplekeys();
 
   fade_out();
 
@@ -939,7 +1028,7 @@ showhighscores(void)
   int scorew, namew;
   int len;
 
-  gcenter(50, "THE CURRENT HIGHSCORES ARE");
+  gcenter(50, "The current highscores are");
 
   scorew=namew=0;
   for(i=0; i<HIGHSCORES; i++) {
@@ -961,7 +1050,7 @@ showhighscores(void)
   }
 
   chcolor=tmp;
-  gcenter(145, "PRESS ANY KEY FOR MAIN MENU.");
+  gcenter(145, "Press any key for the main menu.");
 
   fade_in();
   pressanykey();
@@ -989,25 +1078,24 @@ menu(void)
   int ch;
   static char *menuchoises[NOTHING]= { "I", "C", "H", "P", "A", "Q" };
   static char *menuoptions[NOTHING]= {
-    "INSTRUCTIONS", "CONFIGURATION", "HIGHSCORES", "PLAY GAME", "ABOUT", "QUIT"};
+    "Instructions", "Configuration", "Highscores", 
+    "Play Game", "About", "Quit" };
   int count=0;
 
   clearscr();
-  for(i=0; i<title_rows; i++)
-    puthline(title_pixels+i*title_cols,
-	     (PUSEX-title_cols)>>1,
-	     ((PUSEY+24-title_rows)>>1)+i,
-	     title_cols);
+  putarea(title_pixels, 0, 0, title_cols, title_rows, title_cols,
+	  (PUSEX-title_cols)>>1, (PUSEY+24-title_rows)>>1);
   for(i=0; i<NOTHING; i++) {
     chcolor = TEXTCOLOR;
     printgs(20, 134+i*11, menuoptions[i]);
     chcolor = HIGHLIGHT;
     printgs(20, 134+i*11, menuchoises[i]);
   }
+  printgs(60, 35, "GRATTIS CALLE!");
   chcolor = TEXTCOLOR;
 
   fade_in();
-  keyclose();
+  singlekey();
 
   while(end==NOTHING) {
     ch=getkey();
@@ -1040,16 +1128,16 @@ menu(void)
       count=0;
       break;
     }
-    usleep(10000UL);
+    usleep(50000UL);
 
-    if(++count==800 && end==NOTHING) {
+    if(++count==160 && end==NOTHING) {
       if(!nodemo)
 	end=DEMO;
       count=0;
     }
   }
 
-  keyinit();
+  multiplekeys();
   fade_out();
 
   return(end);
@@ -1072,11 +1160,11 @@ main(int argc, char **argv)
     optc=getopt_long_only(argc, argv,
 			  OPTC SVGA_OPTC X_OPTC, longopts, (int *)0);
     switch(optc) {
-    case EOF:
     case 's':      /* --svgamode */
     case 'm':      /* --noshm */
     case 'X':      /* -display */
     case 'g':      /* -geometry */
+    case '2':      /* --double */
       break;
     case 'e':      /* --nosoundeffects */
       play_sound=0;
@@ -1103,22 +1191,39 @@ main(int argc, char **argv)
 	  gamma_correction = tmp;
       }
       break;
+    case 'j':      /* --step */
+      skip_frames = 1;
+      break;
     case 'h':      /* --help */
       printf("Thrust: version " VERSION " -- the Game\n");
+      printf("Using %s to drive the graphics and\n"
+	     "      %s to drive the keyboard.\n\n",
+	     graphicsname(),
+	     keyname());
       printf("usage: thrust [OPTION]...\n\n"
 	     "  -v, --version\n"
 	     "  -h, --help\n"
 	     "  -d, --nodemo           Do not run the demo.\n"
 	     "  -e, --nosoundeffects   Do not play sound effects.\n"
 	     "  -c, --gamma=Value      Gamma correction of colors.\n"
-	     "  -s, --svgamode=MODE    The format of MODE is G<width>x<height>x<colors>\n"
-	     "  -m, --noshm            Do not use shared memory.\n"
-	     "  -display display-name  See the X man page for details.\n"
-	     "  -geometry geom-spec    See the X man page for details.\n");
+	     "  -j, --step             Only draw every third frame (faster).\n");
+      if(!strcmp(graphicsname(), "SVGA")) {
+	printf("  -s, --svgamode=MODE    The format of MODE is G<width>x<height>x<colors>\n");
+      }
+      if(!strcmp(graphicsname(), "X11")) {
+	printf("  -m, --noshm            Do not use shared memory (slower).\n"
+	       "  -2, --double           Double the size of the window (slower).\n"
+	       "  -display display-name  See the X man page for details.\n"
+	       "  -geometry geom-spec    See the X man page for details.\n");
+      }
+      printf("\n");
       exit(1);
     case 'v':      /* --version */
       printf("Thrust: version " VERSION "\n");
       exit(0);
+    case EOF:
+      if(optind == argc)
+	break;
     default:
       fprintf(stderr, "Thrust: bad usage (see 'thrust -h')\n");
       exit(1);
